@@ -19,7 +19,8 @@ from .systemrdl_node_utility_functions import get_reg_readable_fields, get_reg_w
     get_field_bitmask_hex_string, get_field_inv_bitmask_hex_string, \
     get_field_max_value_hex_string, get_reg_max_value_hex_string, get_fully_qualified_type_name, \
     uses_enum, fully_qualified_enum_type, uses_memory, \
-    get_memory_max_entry_value_hex_string, get_array_typecode, get_memory_width_bytes
+    get_memory_max_entry_value_hex_string, get_array_typecode, get_memory_width_bytes, \
+    get_field_default_value
 
 file_path = os.path.dirname(__file__)
 
@@ -34,6 +35,8 @@ class PythonExporter:
             into the template namespace.
     """
 
+    # pylint: disable=too-few-public-methods
+
     def __init__(self, **kwargs):
 
         user_template_dir = kwargs.pop("user_template_dir", None)
@@ -97,13 +100,13 @@ class PythonExporter:
             node = node.top
 
         package_path = os.path.join(path, node.inst_name)
-        self.create_empty_package(package_path=package_path)
+        self._create_empty_package(package_path=package_path)
 
         modules = [node]
 
         for block in modules:
 
-            self.build_node_type_table(block)
+            self._build_node_type_table(block)
 
             context = {
                 'print': print,
@@ -121,7 +124,7 @@ class PythonExporter:
                 'isinstance': isinstance,
                 'uses_enum' : uses_enum(block),
                 'uses_memory' : uses_memory(block),
-                'get_fully_qualified_type_name': self.lookup_type_name,
+                'get_fully_qualified_type_name': self._lookup_type_name,
                 'get_array_dim': get_array_dim,
                 'get_dependent_component': get_dependent_component,
                 'get_dependent_enum': get_dependent_enum,
@@ -135,7 +138,8 @@ class PythonExporter:
                 'get_reg_readable_fields': get_reg_readable_fields,
                 'get_memory_max_entry_value_hex_string': get_memory_max_entry_value_hex_string,
                 'get_array_typecode': get_array_typecode,
-                'get_memory_width_bytes': get_memory_width_bytes
+                'get_memory_width_bytes': get_memory_width_bytes,
+                'get_field_default_value': get_field_default_value,
             }
 
             context.update(self.user_template_context)
@@ -166,7 +170,7 @@ class PythonExporter:
 
         return [m.inst_name for m in modules]
 
-    def lookup_type_name(self, node: Node) -> str:
+    def _lookup_type_name(self, node: Node) -> str:
         """
         Retreive the unique type name from the current lookup list
 
@@ -180,7 +184,7 @@ class PythonExporter:
 
         return self.node_type_name[node.inst]
 
-    def build_node_type_table(self, node: AddressableNode) -> None:
+    def _build_node_type_table(self, node: AddressableNode) -> None:
         """
         Populate the type name lookup dictionary
 
@@ -209,7 +213,7 @@ class PythonExporter:
                 self.node_type_name[child_inst] = cand_type_name
 
     @staticmethod
-    def create_empty_package(package_path:str) -> None:
+    def _create_empty_package(package_path:str) -> None:
         """
         create the directories and __init__.py files associated with the exported package
 
